<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>MX Snapshot</source>
        <translation>MX スナップショット</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Snapshot location:</source>
        <translation>スナップショットの場所:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="43"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Snapshot is a utility that creates a bootable image (ISO) of your working system that you can use for storage or distribution. You can continue working with undemanding applications while it is running.&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;スナップショットはシステムが動作しているストレージまたはディトリビューションを起動可能なイメージ(ISO)へ生成するユーティリティです。少ない手順で作業を進める事ができます。&lt;br/&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="53"/>
        <source>Used space on / (root) and /home partitions:</source>
        <translation>/ (root) および /home パーティションの空き容量を使用します: </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <location filename="../mainwindow.cpp" line="264"/>
        <source>Snapshot name:</source>
        <translation>スナップショットの名称:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="165"/>
        <source>Select a different snapshot directory</source>
        <translation>差分スナップショットディレクトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>lz4</source>
        <translation>lz4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="469"/>
        <source>lzo</source>
        <translation>lzo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="474"/>
        <source>gzip</source>
        <translation>gzip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="479"/>
        <source>xz</source>
        <translation>xz</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="276"/>
        <source>TextLabel</source>
        <translation>テキストラベル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Downloads</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Documents</source>
        <translation>ドキュメント</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>All of the above</source>
        <translation>上記すべて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Pictures</source>
        <translation>ピクチャー</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <source>Music</source>
        <translation>ミュージック</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Desktop</source>
        <translation>デスクトップ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="336"/>
        <source>Videos</source>
        <translation>ビデオ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="391"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;This option will reset &amp;quot;demo&amp;quot; and &amp;quot;root&amp;quot; passwords to the MX Linux defaults and will not copy any personal accounts created.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;このオプションは、MX Linux のデフォルト「demo」・「root」パスワードをリセットします。作成された個人アカウントにはコピーされません。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="394"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation>アカウントをリセット (他のディトリビューションへ)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>Type of snapshot:</source>
        <translation>スナップショットの種類:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="408"/>
        <source>Preserving accounts (for personal backup)</source>
        <translation>アカウントの保存 (個人的なバックアップ用)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>ISO compression scheme:</source>
        <translation>ISO 圧縮方式：</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Edit Exclusion File</source>
        <translation>除外ファイルの編集</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /etc/mx-snapshot-exclude.list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>exclude network configurations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Options:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="514"/>
        <source>Calculate checksums</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>Display help </source>
        <translation>ヘルプ表示</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="671"/>
        <source>About this application</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="674"/>
        <source>About...</source>
        <translation>情報...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="697"/>
        <source>Quit application</source>
        <translation>アプリケーションの終了</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="700"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="707"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>Next</source>
        <translation>次</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>Back</source>
        <translation>戻る</translation>
    </message>
    <message>
        <source>Used space on / (root): </source>
        <translation type="vanished">/ (root) の空き容量: </translation>
    </message>
    <message>
        <source>Used space on /home: </source>
        <translation type="vanished">/home の空き容量: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="147"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation>スナップショット フォルダがある場所の空き容量 %1：</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="148"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation>/ および /home の圧縮データを保管するには、十分な空き容量がないといけません。必要に応じて、以前生成したスナップショットや保存したコピーを削除することで空き容量を増やすことができます:&#x3000;スナップショット %1 は空き容量の %2 を消費しています。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>Installing </source>
        <translation>インストール中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Error</source>
        <translation>エラー</translation>
    </message>
    <message>
        <source>Could not install </source>
        <translation type="vanished">インストールできません</translation>
    </message>
    <message>
        <source>Building new initrd...</source>
        <translation type="vanished">新しい initrd を構築中...</translation>
    </message>
    <message>
        <source>Copying the new-iso filesystem...</source>
        <translation type="vanished">新たなファイルシステムをコピー中...</translation>
    </message>
    <message>
        <source>Squashing filesystem...</source>
        <translation type="vanished">ファイルシステムに Squash を適用中...</translation>
    </message>
    <message>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="vanished">linuxfsファイルを作成できませんでした。目的のパーティションに十分な空き容量があるか確認してください。</translation>
    </message>
    <message>
        <source>Creating CD/DVD image file...</source>
        <translation type="vanished">CD/DVD イメージファイルを生成中...</translation>
    </message>
    <message>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="vanished">ISOファイルを作成できませんでした。パーティションに十分な空き容量があるかご確認ください。</translation>
    </message>
    <message>
        <source>Making hybrid iso</source>
        <translation type="vanished">ハイブリット ISO 作成中</translation>
    </message>
    <message>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="vanished">MX スナップショットが全て完了！</translation>
    </message>
    <message>
        <source>Snapshot took %1 to finish.</source>
        <translation type="vanished">スナップショットが終了するまで %1 かかりました。</translation>
    </message>
    <message>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="vanished">MX Snapshot をご利用いただきありがとうございます。今度は MX ライブUSBメーカー を起動してください！</translation>
    </message>
    <message>
        <source>Making md5sum</source>
        <translation type="vanished">MD5 チェックサム生成</translation>
    </message>
    <message>
        <source>Cleaning...</source>
        <translation type="vanished">クリーニング中...</translation>
    </message>
    <message>
        <source>Done</source>
        <translation type="vanished">完了</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>Please wait.</source>
        <translation>お待ち下さい。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="243"/>
        <source>Please wait. Calculating used disk space...</source>
        <translation>お待ち下さい。使用する空き容量を計算しています...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Settings</source>
        <translation>設定中</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Snapshot will use the following settings:*</source>
        <translation>スナップショットは次の設定を使用します:*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="263"/>
        <source>- Snapshot directory:</source>
        <translation>- スナップショット ディレクトリ: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="265"/>
        <source>- Kernel to be used:</source>
        <translation>- 使用するカーネル: </translation>
    </message>
    <message>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="vanished">現在のカーネルは選択された圧縮アルゴリズムをサポートしていないので、設定ファイルを編集して別のアルゴリズムを選択してください。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="269"/>
        <source>Final chance</source>
        <translation>最終確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="270"/>
        <source>Snapshot now has all the information it needs to create an ISO from your running system.</source>
        <translation>Snapshot には,、現在稼働中のシステムから ISO を生成するための全ての情報があります。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="271"/>
        <source>It will take some time to finish, depending on the size of the installed system and the capacity of your computer.</source>
        <translation>インストールを行うシステムのサイズとコンピュータの性能によって、完了までにかかる時間が異なります。</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="272"/>
        <source>OK to start?</source>
        <translation>OK で開始します</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="282"/>
        <source>Could not create temporary directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>Output</source>
        <translation>出力</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Edit Boot Menu</source>
        <translation>起動メニューの編集</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>The program will now pause to allow you to edit any files in the work directory. Select Yes to edit the boot menu or select No to bypass this step and continue creating the snapshot.</source>
        <translation>プログラムは、作業ディレクトリで任意ファイルを編集できるように、一時休止しています。「はい」を選んで起動メニューを編集するか、「いいえ」を選んでこのステップを飛ばしてスナップショットの作成を継続するかを選んでください。</translation>
    </message>
    <message>
        <source>Success</source>
        <translation type="vanished">成功</translation>
    </message>
    <message>
        <source>All finished!</source>
        <translation type="vanished">すべて完了しました！</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>About %1</source>
        <translation> %1 について</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="390"/>
        <source>Version: </source>
        <translation>バージョン: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="391"/>
        <source>Program for creating a live-CD from the running system for MX Linux</source>
        <translation>実行している MX Linux を元にライブCD を生成するプログラム</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="394"/>
        <source>%1 License</source>
        <translation>%1 ライセンス</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="408"/>
        <source>%1 Help</source>
        <translation>%1 のヘルプ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="416"/>
        <source>Select Snapshot Directory</source>
        <translation>スナップショット ディレクトリを選択</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>Are you sure you want to quit the application?</source>
        <translation>本当にアプリケーションを終了しますか？</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="33"/>
        <source>License</source>
        <translation>ライセンス</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <location filename="../about.cpp" line="44"/>
        <source>Changelog</source>
        <translation>更新履歴</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="35"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>&amp;Close</source>
        <translation>&amp;閉じる</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">エラー</translation>
    </message>
    <message>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="vanished">現在のカーネルは Squashfs をサポートしてないので続行できません。</translation>
    </message>
    <message>
        <source>You must run this program as root.</source>
        <translation type="vanished">このプログラムは root で実行する必要があります。</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Tool used for creating a live-CD from the running system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Use CLI only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>Output directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>Output filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="63"/>
        <source>name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Name a different kernel to use other than the default running kernel, use format returned by &apos;uname -r&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>Or the full path: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Create a monthly snapshot, add &apos;Month&apos; name in the ISO name, skip used space calculation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>This option sets reset-accounts and compression to defaults, arguments changing those items will be ignored</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Don&apos;t calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>Option to fix issue with calculating checksums on preempt_rt kernels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Resetting accounts (for distribution to others)</source>
        <translation type="unfinished">アカウントをリセット (他のディトリビューションへ)</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>Calculate checksums for resulting ISO file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Skip calculating free space to see if the resulting ISO will fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Exclude main folders, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Desktop, Documents, Downloads, Music, Networks, Pictures, Videos.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Use the option one time for each item you want to exclude</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>one item</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Compression format, valid choices: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>You must run this program as root.</source>
        <translation type="unfinished">このプログラムは root で実行する必要があります。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="123"/>
        <location filename="../main.cpp" line="178"/>
        <location filename="../settings.cpp" line="204"/>
        <source>Error</source>
        <translation type="unfinished">エラー</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <location filename="../main.cpp" line="124"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="65"/>
        <source>version, or path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="179"/>
        <location filename="../settings.cpp" line="211"/>
        <source>Current kernel doesn&apos;t support Squashfs, cannot continue.</source>
        <translation type="unfinished">現在のカーネルは Squashfs をサポートしてないので続行できません。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="105"/>
        <location filename="../main.cpp" line="130"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../batchprocessing.cpp" line="59"/>
        <source>The program will pause the build and open the boot menu in your text editor.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="89"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="107"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="204"/>
        <source>Could not find a usable kernel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="285"/>
        <source>Used space on / (root): </source>
        <translation type="unfinished">/ (root) の空き容量: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="288"/>
        <source>estimated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="297"/>
        <source>Used space on /home: </source>
        <translation type="unfinished">/home の空き容量: </translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="349"/>
        <source>Free space on %1, where snapshot folder is placed: </source>
        <translation type="unfinished">スナップショット フォルダがある場所の空き容量 %1：</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="351"/>
        <source>The free space should be sufficient to hold the compressed data from / and /home

      If necessary, you can create more available space
      by removing previous snapshots and saved copies:
      %1 snapshots are taking up %2 of disk space.
</source>
        <translation type="unfinished">/ および /home の圧縮データを保管するには、十分な空き容量がないといけません。必要に応じて、以前生成したスナップショットや保存したコピーを削除することで空き容量を増やすことができます:&#x3000;スナップショット %1 は空き容量の %2 を消費しています。</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="366"/>
        <source>Desktop</source>
        <translation type="unfinished">デスクトップ</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="367"/>
        <source>Documents</source>
        <translation type="unfinished">ドキュメント</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="368"/>
        <source>Downloads</source>
        <translation type="unfinished">ダウンロード</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="369"/>
        <source>Music</source>
        <translation type="unfinished">ミュージック</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="370"/>
        <source>Networks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="371"/>
        <source>Pictures</source>
        <translation type="unfinished">ピクチャー</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="372"/>
        <source>Videos</source>
        <translation type="unfinished">ビデオ</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="182"/>
        <source>Interrupted or failed to complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Work</name>
    <message>
        <location filename="../work.cpp" line="36"/>
        <location filename="../work.cpp" line="122"/>
        <location filename="../work.cpp" line="129"/>
        <location filename="../work.cpp" line="135"/>
        <location filename="../work.cpp" line="275"/>
        <location filename="../work.cpp" line="292"/>
        <location filename="../work.cpp" line="329"/>
        <location filename="../work.cpp" line="374"/>
        <location filename="../work.cpp" line="405"/>
        <source>Error</source>
        <translation type="unfinished">エラー</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="37"/>
        <source>Current kernel doesn&apos;t support selected compression algorithm, please edit the configuration file and select a different algorithm.</source>
        <translation type="unfinished">現在のカーネルは選択された圧縮アルゴリズムをサポートしていないので、設定ファイルを編集して別のアルゴリズムを選択してください。</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="91"/>
        <source>Calculating total size of excluded files...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="100"/>
        <source>Calculating size of root...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="123"/>
        <location filename="../work.cpp" line="130"/>
        <location filename="../work.cpp" line="136"/>
        <source>There&apos;s not enough free space on your target disk, you need at least %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="124"/>
        <location filename="../work.cpp" line="131"/>
        <location filename="../work.cpp" line="137"/>
        <source>You have %1 free space on %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="162"/>
        <source>Cleaning...</source>
        <translation type="unfinished">クリーニング中...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="178"/>
        <location filename="../work.cpp" line="181"/>
        <location filename="../work.cpp" line="314"/>
        <source>Done</source>
        <translation type="unfinished">完了</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="216"/>
        <source>Copying the new-iso filesystem...</source>
        <translation type="unfinished">新たなファイルシステムをコピー中...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="244"/>
        <source>Could not create temp directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="273"/>
        <source>Squashing filesystem...</source>
        <translation type="unfinished">ファイルシステムに Squash を適用中...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="275"/>
        <source>Could not create linuxfs file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished">linuxfsファイルを作成できませんでした。目的のパーティションに十分な空き容量があるか確認してください。</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="290"/>
        <source>Creating CD/DVD image file...</source>
        <translation type="unfinished">CD/DVD イメージファイルを生成中...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="292"/>
        <source>Could not create ISO file, please check whether you have enough space on the destination partition.</source>
        <translation type="unfinished">ISOファイルを作成できませんでした。パーティションに十分な空き容量があるかご確認ください。</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="299"/>
        <source>Making hybrid iso</source>
        <translation type="unfinished">ハイブリット ISO 作成中</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="315"/>
        <source>Success</source>
        <translation type="unfinished">成功</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="315"/>
        <source>MX Snapshot completed sucessfully!</source>
        <translation type="unfinished">MX スナップショットが全て完了！</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="316"/>
        <source>Snapshot took %1 to finish.</source>
        <translation type="unfinished">スナップショットが終了するまで %1 かかりました。</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="317"/>
        <source>Thanks for using MX Snapshot, run MX Live USB Maker next!</source>
        <translation type="unfinished">MX Snapshot をご利用いただきありがとうございます。今度は MX ライブUSBメーカー を起動してください！</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="326"/>
        <source>Installing </source>
        <translation type="unfinished">インストール中</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="329"/>
        <source>Could not install </source>
        <translation type="unfinished">インストールできません</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="339"/>
        <source>Calculating checksum...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="374"/>
        <source>Could not create working directory. </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../work.cpp" line="383"/>
        <source>Building new initrd...</source>
        <translation type="unfinished">新しい initrd を構築中...</translation>
    </message>
    <message>
        <location filename="../work.cpp" line="405"/>
        <source>Could not find %1 file, cannot continue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
